@@ -1113,7 +1113,7 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
             past_returns.to_excel(writer, sheet_name='common')
             writer.save()
 
-    return payload_message
+    return payload_message, freq_aggregated_df
 
 
 
